@@ -143,6 +143,58 @@ class TestBasicFunctions(unittest.TestCase):
         expected = [[], [2, 2], [3]]
         self.assertListEqual(expected, result)
 
+        grades = [
+            {
+                "userid": 1,
+                "grade": "A"
+            }, {
+                "userid": 1,
+                "grade": "B"
+            }, {
+                "userid": 2,
+                "grade": "B"
+            }, {
+                "userid": 2,
+                "grade": "B"
+            }
+        ]
+        students = [
+            {
+                "id": 1,
+                "name": "Jakob"
+            }, {
+                "id": 2,
+                "name": "Johan"
+            }
+        ]
+        names = From(students).groupJoin(
+            grades,
+            innerKey = lambda x: x["id"],
+            outerKey = lambda x: x["userid"],
+            innerTransform = lambda x: x["name"],
+            outerTransform = lambda x: x["grade"]
+        ).select(lambda x: x.inner).toList()
+
+        expected = ["Jakob", "Johan"]
+        self.assertListEqual(
+            names,
+            expected
+        )
+
+        grades = From(students).groupJoin(
+            grades,
+            innerKey = lambda x: x["id"],
+            outerKey = lambda x: x["userid"],
+            innerTransform = lambda x: x["name"],
+            outerTransform = lambda x: x["grade"]
+        ).select(lambda x: x.outer).toList()
+
+        expected = [["A","B"], ["B","B"]]
+        self.assertListEqual(
+            grades,
+            expected
+        )
+
     def test_group_by(self):
         
         subject = [
@@ -200,6 +252,28 @@ class TestBasicFunctions(unittest.TestCase):
         expected = [3,4]
         self.assertListEqual(result,expected)
 
+        subjectA = [
+            {
+                "id": 1,
+                "value": 3
+            }, {
+                "id": 2,
+                "value": 4
+            }
+        ]
+        subjectB = [
+            {
+                "id": 2,
+                "value": 4
+            }, {
+                "id": 3,
+                "value": 5
+            }
+        ]
+        result = From(subjectA).intersect(subjectB, key=lambda x: x["id"]).select(lambda x: x["value"]).toList()
+        expected = [4]
+        self.assertListEqual(expected, result)
+
     def test_join(self):
         subject1 = [
             {
@@ -272,5 +346,20 @@ class TestBasicFunctions(unittest.TestCase):
         ]
         self.assertListEqual(expected, result)
 
+    def test_concat(self):
+        subjectA = [
+            { "value": 1},
+            { "value": 2}
+        ]
+        subjectB = [
+            { "value": 3 },
+            { "value": 4 }
+        ]
+        result = From(subjectA).select(lambda x: x["value"]).concat(
+            From(subjectB).select(lambda x: x["value"])
+        ).toList()
+        expected = [1, 2, 3, 4]
+        self.assertListEqual(result, expected)
+
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
